@@ -5,7 +5,7 @@ package DataDog::DogStatsd;
 use strict;
 use warnings;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use IO::Socket::INET;
 
@@ -43,6 +43,7 @@ sub _socket {
 
 sub namespace {
 	my $self = shift;
+        return $self->{'namespace'} unless @_;
 	$self->{'namespace'} = shift;
 }
 
@@ -287,6 +288,11 @@ Sends a value to be tracked as a set to the statsd server.
 =head2 event
 
 	$statsd->event('event title', 'event text', { tags => ['tag1, 'tag2'] });
+	$statsd->event('event title', 'event text', { tags => ['tag1', 'tag2'], alert_type => 'error'});
+
+Sends an event indicating a specific incident occurring. 
+
+Use alert_type option to specify the kind of event, available options are error, warning, info, and success.
 
 =head1 AUTHORS
 
